@@ -255,6 +255,24 @@ class SlimtaState(object):
                 credentials = get_relay_credentials(options.get('credentials'))
                 kwargs['credentials'] = credentials
             new_relay = StaticSmtpRelay(**kwargs)
+        elif options.type == 'lmtp':
+            from slimta.relay.smtp.static import StaticLmtpRelay
+            from .helpers import fill_hostname_template, get_relay_credentials
+            kwargs = {}
+            kwargs['host'] = options.get('host', 'localhost')
+            kwargs['port'] = options.get('port', 24)
+            kwargs['connect_timeout'] = options.get('connect_timeout', 30)
+            kwargs['command_timeout'] = options.get('command_timeout', 30)
+            kwargs['data_timeout'] = options.get('data_timeout', 60)
+            kwargs['idle_timeout'] = options.get('idle_timeout', 10)
+            kwargs['pool_size'] = options.get('concurrent_connections', 5)
+            kwargs['ehlo_as'] = fill_hostname_template(options.get('ehlo_as'))
+            if 'tls' in options:
+                kwargs['tls'] = self._get_tls_options(options.tls)
+            if 'credentials' in options:
+                credentials = get_relay_credentials(options.get('credentials'))
+                kwargs['credentials'] = credentials
+            new_relay = StaticLmtpRelay(**kwargs)
         elif options.type == 'http':
             from slimta.relay.http import HttpRelay
             from .helpers import fill_hostname_template
@@ -293,12 +311,16 @@ class SlimtaState(object):
         new_queue = None
         relay_name = options.get('relay')
         relay = self._start_relay(relay_name) if relay_name else None
+        bounce_queue_name = options.get('bounce_queue', name)
+        bounce_queue = self._start_queue(bounce_queue_name) \
+                       if bounce_queue_name != name else None
         if options.type == 'memory':
             from slimta.queue import Queue
             from slimta.queue.dict import DictStorage
             store = DictStorage()
             backoff = build_backoff_function(options.get('retry'))
-            new_queue = Queue(store, relay, backoff=backoff)
+            new_queue = Queue(store, relay, backoff=backoff,
+                              bounce_queue=bounce_queue)
             new_queue.start()
         elif options.type == 'disk':
             from slimta.queue import Queue
@@ -308,7 +330,8 @@ class SlimtaState(object):
             tmp_dir = options.get('tmp_dir')
             store = DiskStorage(env_dir, meta_dir, tmp_dir)
             backoff = build_backoff_function(options.get('retry'))
-            new_queue = Queue(store, relay, backoff=backoff)
+            new_queue = Queue(store, relay, backoff=backoff,
+                              bounce_queue=bounce_queue)
             new_queue.start()
         elif options.type == 'redis':
             from slimta.queue import Queue
@@ -328,7 +351,8 @@ class SlimtaState(object):
                 kwargs['prefix'] = options.prefix
             store = RedisStorage(**kwargs)
             backoff = build_backoff_function(options.get('retry'))
-            new_queue = Queue(store, relay, backoff=backoff)
+            new_queue = Queue(store, relay, backoff=backoff,
+                              bounce_queue=bounce_queue)
             new_queue.start()
         elif options.type == 'rackspace':
             from slimta.queue import Queue
@@ -358,7 +382,8 @@ class SlimtaState(object):
                         queue_name=options.queue_name,
                         tls=tls, timeout=10.0)
             store = CloudStorage(cloud_files, cloud_queues)
-            new_queue = Queue(store, relay, backoff=backoff)
+            new_queue = Queue(store, relay, backoff=backoff,
+                              bounce_queue=bounce_queue)
             new_queue.start()
         elif options.type == 'aws':
             from slimta.queue import Queue
@@ -387,7 +412,8 @@ class SlimtaState(object):
                 sqs_queue = sqs_conn.create_queue(options.queue_name)
                 sqs = SimpleQueueService(sqs_queue, timeout=10.0)
             store = CloudStorage(s3, sqs)
-            new_queue = Queue(store, relay, backoff=backoff)
+            new_queue = Queue(store, relay, backoff=backoff,
+                              bounce_queue=bounce_queue)
             new_queue.start()
         elif options.type == 'proxy':
             from slimta.queue.proxy import ProxyQueue
